import path from 'path';
import { fileURLToPath } from 'url';

const __dirname = path.dirname(fileURLToPath(import.meta.url));

const dirs = {
    src: path.resolve(__dirname, './src'),
    dist: path.resolve(__dirname, './dist'),
};

import esbuild from 'esbuild';
import browserslistToEsbuild from 'browserslist-to-esbuild';

(async function() {
    try {
        await esbuild.build({
            entryPoints: [
                path.resolve(dirs.src, './index.ts'),
            ],
            outdir: dirs.dist,
            format: 'esm',
            bundle: true,
            target: browserslistToEsbuild(),
            resolveExtensions: ['.ts', '.d.ts'],
        });
    } catch (e) {
        console.error('BUILD');
        console.error(e);

        process.exit(1);
    }
})();
